#!/usr/local/bin/bash

CONFFILE=/usr/local/etc/qmrtg.conf
QMRTG_DBPATH=/tmp/qmrtg
VERBOSITYLEVEL=0

########### don't edit below ####################

 # called when something is wrong on the command line
usage() {
        echo "Usage:"
        echo "`basename $0` query_type logdir"
        echo "see qmrtg(1) for details."
}


 # checking for sane call
[ -z "$1" ] && { usage ; exit 1; } 
[ -z "$2" ] && { usage ; exit 1; }

 # loads settings from the config file, if it exists
[ -f $CONFFILE ] && . $CONFFILE


[ $VERBOSITYLEVEL -ge 1 ] && { echo >>$DEBUG ; echo "*************** session started - `date` - ***************" >>$DEBUG ; }

DBFILE=$1.last
OUTPUT1=0
OUTPUT2=0

 # checking the query type argument
for (( i=1; $i <= ${#AVAILCMDS[*]}; $((i++)) )) ;
do 
	[ $1 = ${AVAILCMDS[$i]} ] && { COMMAND=${ACTUALCMD[$i]} ; break; }
done

 # the "type" specified is not known from $CONFFILE
[ -z $COMMAND ] && {
        echo "Error. \"type\" must be one of:"
        for (( i=1; $i <= ${#AVAILCMDS[*]}; $((i++)) )) ;
        do
                echo "-> ${AVAILCMDS[$i]}"
        done
        echo "--"
        echo "Have a look at $CONFFILE. Terminating."
        exit 1
}


[ $VERBOSITYLEVEL -ge 3 ] && echo "query: $1 - then command: $COMMAND" >>$DEBUG


 # checking the logdir argument
[ -d $2 ] && [ -r $2 ] || { echo "Unable to access $2. Terminating." ; exit 2; }
LOGDIR=$2

[ $VERBOSITYLEVEL -ge 3 ] && echo "$COMMAND: log directory: $LOGDIR" >>$DEBUG 

[ -z $QMRTG_DBPATH ] && exit 1

[ $VERBOSITYLEVEL -ge 2 ] && echo "$COMMAND: database directory: $QMRTG_DBPATH" >>$DEBUG

qmrtgLoadLastEntry() {
	[ -f "$QMRTG_DBPATH/$DBFILE" ] || { echo "000000000000000000000000" ; [ $VERBOSITYLEVEL -ge 1 ] && echo "$COMMAND: dbfile $QMRTG_DBPATH/$DBFILE does not exist. Reporting from time 0." >>$DEBUG ; return ; }

	echo `cat $QMRTG_DBPATH/$DBFILE`
}

 # called for each log file to be parsed
 # $1 = the logfile
qmrtgparse() {
	[ -z "$1" ] && return;
	[ -f "$1" ] || return;

	[ $VERBOSITYLEVEL -ge 2 ] && echo "$COMMAND: have to check logfile $1" >>$DEBUG

	[ $VERBOSITYLEVEL -ge 2 ] && echo "$COMMAND: Calling $COMMAND $LASTENTRY $1" >>$DEBUG

	 # skipping useless "0" lines
	RETV=`$COMMAND $LASTENTRY "$1" 2>>$DEBUG`
	[ -z "$RETV" ] && { [ $VERBOSITYLEVEL -ge 1 ] && echo "$COMMAND: No output from $COMMAND" >>$DEBUG ; return ; }  || { [ $VERBOSITYLEVEL -ge 1 ] && echo "$COMMAND: $COMMAND returns: $RETV" >>$DEBUG ; }

	 # the first line output is the # of remote deliveries
	OUTPUT1=$(( $OUTPUT1 + `echo $RETV | awk '{ print $1 }'` ))
	[ $VERBOSITYLEVEL -ge 2 ] && echo "$COMMAND: from file $1: `echo $RETV | awk '{ print $1 }'` entries found. Current total: $OUTPUT1" >>$DEBUG
	 # the second line output is the # of local deliveries
	OUTPUT2=$(( $OUTPUT2 + `echo $RETV | awk '{ print $2 }'` ))
	[ $VERBOSITYLEVEL -ge 2 ] && echo "$COMMAND: from file $1: `echo $RETV | awk '{ print $2 }'` entries found. Current total: $OUTPUT2" >>$DEBUG
	 # the 3rd one is the timestamp of the last entry analyzed
	NEWTIMESTAMP=`echo $RETV | awk '{ print $3 }'`

	[ $VERBOSITYLEVEL -ge 1 ] && echo "$COMMAND: updating timestamp to: $NEWTIMESTAMP" >>$DEBUG
	updateTimestamp $NEWTIMESTAMP
}


 # updates the timestamp entry to the one of the last line analyzed 
updateTimestamp() {
	[ -z "$1" ] && return;
	echo $1 > $QMRTG_DBPATH/$DBFILE
	
	[ $VERBOSITYLEVEL -ge 3 ] && echo "$COMMAND: timestamp called for: $1 ; timestamp from db: `cat $QMRTG_DBPATH/$DBFILE`" >>$DEBUG
}


# this is main()


fileslist=`ls $LOGDIR/@*`

[ $VERBOSITYLEVEL -ge 6 ] && echo "$COMMAND: files to scan (excluding \"current\"): $fileslist" >>$DEBUG

for i in $fileslist ; do {
	LASTENTRY=`qmrtgLoadLastEntry` 
	[ $VERBOSITYLEVEL -ge 6 ] && echo "$COMMAND: : $fileslist" >>$DEBUG
	foo=`basename $i | sed s/@//g | awk -F'.' '{ print $1 }'`
	test "$LASTENTRY" '<' "$foo" && qmrtgparse "$i"
}; done

[ $VERBOSITYLEVEL -ge 1 ] && echo "$COMMAND: scanning for \"current\"" >>$DEBUG

 # finally unconditionally parse the last logfile "current"
qmrtgparse "$LOGDIR/current"

if ( [ ! -z $OUTPUT1 ] ) ; then {
	echo $OUTPUT1
	if ( [ $VERBOSITYLEVEL -ge 1 ] ); then echo "$COMMAND: grand total1: $OUTPUT1" >>$DEBUG; fi
} else {
	echo 0
	echo "$COMMAND: HEI!!! The first output value is empty!!" >>$DEBUG
}; fi

if ( [ ! -z $OUTPUT2 ] ); then {
	echo $OUTPUT2
	if ( [ $VERBOSITYLEVEL -ge 1 ] ); then echo "$COMMAND: grand total2: $OUTPUT2" >>$DEBUG; fi
} else {
	echo 0
	echo "$COMMAND: HEI!!! The second output value is empty!!" >>$DEBUG
}; fi 
echo `uptime | awk -F',' '{ print $1 }'`
echo `hostname`
